(* generated by dune *)

(** @canonical Ctypes_top.Ctypes_printers *)
module Ctypes_printers = Ctypes_top__Ctypes_printers

(** @canonical Ctypes_top.Install_ctypes_printers *)
module Install_ctypes_printers = Ctypes_top__Install_ctypes_printers
